@@ -2,7 +2,7 @@ import os
 import json
 
 
-config_file_path = (os.environ.get('AUTOMLAPI_CONFIG_FILE_PATH') or 
+config_file_path = (os.environ.get('NPAWS_CONFIG_FILE_PATH') or 
                     os.path.join(os.path.expanduser("~"), 'npaws.cfg'))
 CONFIG = json.load(open(config_file_path, 'r'))
 
