@@ -296,7 +296,7 @@ class RDSClient():
         """
         """
         assert task_type in ("CLS", "EXT")
-        query = f"SELECT * FROM neuralplatform_basemodel WHERE taskType = {task_type}"
+        query = f"SELECT * FROM neuralplatform_basemodel WHERE taskType = '{task_type}';"
         return self.select_query(query)
 
     def insert_model(self,
@@ -329,12 +329,21 @@ class RDSClient():
         query = f"SELECT * FROM neuralplatform_model WHERE id = (SELECT bestModel_id FROM neuralplatform_version WHERE version_id = {version_id});"
         return self.select_query(query, fetchone=True)
     
+    def update_version_model(self,
+                             version_id: int,
+                             model_id: int):
+        """
+        """
+        query = f"UPDATE neuralplatform_version SET bestModel_id = {model_id} WHERE id = {version_id};"
+        return self.update_query(query)
+    
     def get_model_params(self,
                          model_id: int) -> dict:
         """
         """
         query = f"SELECT hyperparams FROM neuralplatform_model WHERE id={model_id};"
-        return json.loads(self.select_query(query, fetchone=True))
+        result = self.select_query(query, fetchone=True)
+        return json.loads(result['hyperparams'])
     
     def insert_class_performance(self,
                                  model_id: int,
