@@ -17,10 +17,10 @@ class S3Client(Boto3Client):
                      project_name: str,
                      version_id: int,
                      model_id: int,
-                     filepath: str,
-                     filename: str = 'model.h5') -> str:
+                     filepath: str = 'model.h5') -> str:
         """
         """
+        filename = os.path.basename(filepath)
         file_path = f"{project_name}/versions/{version_id}/models/{model_id}/{filename}"
         self.upload_file(filepath, Bucket=bucket, Key=file_path)
         return file_path
